"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const metadata_1 = require("../metadata");
/**
 * Annotates this parameter to receive the request body.
 */
function body(settings = {}) {
    return (target, propertyKey, methodIndex) => {
        const partialArgs = [];
        partialArgs[methodIndex] = {
            type: "body"
        };
        metadata_1.appendControllerMethodMetadata(target[propertyKey], {
            request: {
                required: settings.required,
                schema: settings.schema
            },
            handlerArgs: partialArgs
        });
    };
}
exports.body = body;
/**
 * Annotates this parameter to receive the given path parameter.
 *
 * If the path parameter has a definition in the method decorator,
 * it will be cocerced to the type supplied in that definition.
 * Otherwise, it will be a string.
 */
function pathParam(paramName, settings = {}) {
    return (target, propertyKey, methodIndex) => {
        const partialArgs = [];
        partialArgs[methodIndex] = {
            type: "pathParam",
            paramName: paramName
        };
        metadata_1.appendControllerMethodMetadata(target[propertyKey], {
            pathParams: {
                [paramName]: {
                    schema: settings.schema
                }
            },
            handlerArgs: partialArgs
        });
    };
}
exports.pathParam = pathParam;
/**
 * Annotates this parameter to receive the given query parameter.
 *
 * If the path parameter has a definition in the method decorator,
 * it will be cocerced to the type supplied in that definition.
 * Otherwise, it will be a string.
 */
function queryParam(paramName, settings = {}) {
    return (target, propertyKey, methodIndex) => {
        const partialArgs = [];
        partialArgs[methodIndex] = {
            type: "queryParam",
            paramName: paramName
        };
        metadata_1.appendControllerMethodMetadata(target[propertyKey], {
            queryParams: {
                [paramName]: {
                    schema: settings.schema,
                    required: settings.required
                }
            },
            handlerArgs: partialArgs
        });
    };
}
exports.queryParam = queryParam;
/**
 * Annotates the parameter to receive the express Request object.
 */
function expressRequest() {
    return (target, propertyKey, methodIndex) => {
        const partialArgs = [];
        partialArgs[methodIndex] = {
            type: "request"
        };
        metadata_1.appendControllerMethodMetadata(target[propertyKey], {
            handlerArgs: partialArgs
        });
    };
}
exports.expressRequest = expressRequest;
/**
 * Annotates the parameter to receive the express Response object.
 */
function expressResponse() {
    return (target, propertyKey, methodIndex) => {
        const partialArgs = [];
        partialArgs[methodIndex] = {
            type: "response"
        };
        metadata_1.appendControllerMethodMetadata(target[propertyKey], {
            handlerArgs: partialArgs
        });
    };
}
exports.expressResponse = expressResponse;
//# sourceMappingURL=controller-method-args.js.map