"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_method_1 = require("../metadata/controller-method");
function get(pathOrSettings, settings) {
    return method("GET", pathOrSettings, settings);
}
exports.get = get;
function head(pathOrSettings, settings) {
    return method("HEAD", pathOrSettings, settings);
}
exports.head = head;
function post(pathOrSettings, settings) {
    return method("POST", pathOrSettings, settings);
}
exports.post = post;
function put(pathOrSettings, settings) {
    return method("PUT", pathOrSettings, settings);
}
exports.put = put;
function del(pathOrSettings, settings) {
    return method("DELETE", pathOrSettings, settings);
}
exports.del = del;
function patch(pathOrSettings, settings) {
    return method("PATCH", pathOrSettings, settings);
}
exports.patch = patch;
function method(method, pathOrSettings, settings) {
    let path = "/";
    if (typeof pathOrSettings === "string") {
        path = pathOrSettings;
    }
    else if (pathOrSettings && typeof pathOrSettings === "object") {
        settings = pathOrSettings;
    }
    if (!settings) {
        settings = {};
    }
    return (target, propertyKey) => {
        controller_method_1.appendControllerMethodMetadata(target[propertyKey], {
            method,
            path,
            summary: settings.summary,
            description: settings.description,
            tags: settings.tags
        });
    };
}
exports.method = method;
function response(statusCode, settings = {}) {
    return (target, propertyKey) => {
        controller_method_1.appendControllerMethodMetadata(target[propertyKey], {
            responses: {
                [statusCode]: {
                    description: settings.description,
                    schema: settings.schema
                }
            }
        });
    };
}
exports.response = response;
/**
 * Specify the swagger documentation for the method.
 *
 * Using this decorator suppresses the auto-generation of swagger documentation for this method.
 *
 * @param swaggerPathDocs Additional swagger documentation to apply to the path.
 */
function swaggerMethod(swaggerPathDocs) {
    return (target, propertyKey) => {
        controller_method_1.appendControllerMethodMetadata(target[propertyKey], {
            swaggerOverride: swaggerPathDocs
        });
    };
}
exports.swaggerMethod = swaggerMethod;
//# sourceMappingURL=controller-method.js.map