"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const controller_method_1 = require("./controller-method");
const metadata_1 = require("../metadata");
describe("Controller Method Decorators", function () {
    describe("@get", function () {
        const path = "/foo/bar";
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.get(path)
        ], TestClass.prototype, "testMethod", null);
        it("sets the http method", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.method).toEqual("GET");
        });
        it("sets the path", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.path).toEqual(path);
        });
    });
    describe("@head", function () {
        const path = "/foo/bar";
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.head(path)
        ], TestClass.prototype, "testMethod", null);
        it("sets the http method", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.method).toEqual("HEAD");
        });
        it("sets the path", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.path).toEqual(path);
        });
    });
    describe("@post", function () {
        const path = "/foo/bar";
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.post(path)
        ], TestClass.prototype, "testMethod", null);
        it("sets the http method", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.method).toEqual("POST");
        });
        it("sets the path", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.path).toEqual(path);
        });
    });
    describe("@put", function () {
        const path = "/foo/bar";
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.put(path)
        ], TestClass.prototype, "testMethod", null);
        it("sets the http method", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.method).toEqual("PUT");
        });
        it("sets the path", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.path).toEqual(path);
        });
    });
    describe("@del", function () {
        const path = "/foo/bar";
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.del(path)
        ], TestClass.prototype, "testMethod", null);
        it("sets the http method", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.method).toEqual("DELETE");
        });
        it("sets the path", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.path).toEqual(path);
        });
    });
    describe("@patch", function () {
        const path = "/foo/bar";
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.patch(path)
        ], TestClass.prototype, "testMethod", null);
        it("sets the http method", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.method).toEqual("PATCH");
        });
        it("sets the path", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.path).toEqual(path);
        });
    });
    describe("@method", function () {
        describe("(method)", function () {
            const httpMethod = "TRACE";
            class TestClass {
                testMethod() { }
            }
            __decorate([
                controller_method_1.method(httpMethod)
            ], TestClass.prototype, "testMethod", null);
            it("sets the http method", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.method).toEqual(httpMethod);
            });
            it("sets the path to '/'", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.path).toEqual("/");
            });
        });
        describe("(method, path)", function () {
            const httpMethod = "TRACE";
            const path = "/foo/bar";
            class TestClass {
                testMethod() { }
            }
            __decorate([
                controller_method_1.method(httpMethod, path)
            ], TestClass.prototype, "testMethod", null);
            it("sets the http method", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.method).toEqual(httpMethod);
            });
            it("sets the path", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.path).toEqual(path);
            });
        });
        describe("(method, settings)", function () {
            const httpMethod = "TRACE";
            const settings = {
                summary: "Test method",
                description: "This is a test method",
                tags: ["Test"]
            };
            class TestClass {
                testMethod() { }
            }
            __decorate([
                controller_method_1.method(httpMethod, settings)
            ], TestClass.prototype, "testMethod", null);
            it("sets the http method", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.method).toEqual(httpMethod);
            });
            it("sets the summary", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.summary).toEqual(settings.summary);
            });
            it("sets the description", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.description).toEqual(settings.description);
            });
            it("sets the tags", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.tags).toEqual(settings.tags);
            });
        });
        describe("(method, path, settings)", function () {
            const httpMethod = "TRACE";
            const path = "/foo/bar";
            const settings = {
                summary: "Test method",
                description: "This is a test method",
                tags: ["Test"]
            };
            class TestClass {
                testMethod() { }
            }
            __decorate([
                controller_method_1.method(httpMethod, path, settings)
            ], TestClass.prototype, "testMethod", null);
            it("sets the path", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.path).toEqual(path);
            });
            it("sets the http method", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.method).toEqual(httpMethod);
            });
            it("sets the summary", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.summary).toEqual(settings.summary);
            });
            it("sets the description", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.description).toEqual(settings.description);
            });
            it("sets the tags", function () {
                const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
                expect(metadata.tags).toEqual(settings.tags);
            });
        });
    });
    describe("@response", function () {
        const code = 201;
        const description = "Widget Created";
        const schema = {
            type: "object"
        };
        class TestClass {
            testMethod() { }
        }
        __decorate([
            controller_method_1.response(code, { description, schema })
        ], TestClass.prototype, "testMethod", null);
        it("sets the response to the appropriate code", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.responses[code]).toBeDefined();
        });
        it("sets the result description", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.responses[code].description).toEqual(description);
        });
        it("sets the result schema", function () {
            const metadata = metadata_1.getControllerMethodMetadata(TestClass.prototype["testMethod"]);
            expect(metadata.responses[code].schema).toEqual(schema);
        });
    });
});
//# sourceMappingURL=controller-method.spec.js.map