"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class ResultBuilder {
    constructor(body) {
        this.statusCode = 200;
        this.headers = {};
        this.cookies = {};
        this.body = body;
    }
    /**
     * Sets the status message of the result.
     * @param status The status code to return.
     */
    status(status) {
        this.statusCode = status;
        return this;
    }
    /**
     * Sets a result header.
     * @param name The name of the header to set.
     * @param value The value of the header to set.
     */
    header(name, value) {
        this.headers[name] = value;
        return this;
    }
    /**
     * Sets a cookie on the result.
     * @param name The name of the cookie.
     * @param value The value of the cookie.
     * @param settings Additional cookie settings.
     */
    cookie(name, value, settings) {
        this.cookies[name] = Object.assign({ value }, (settings || {}));
        return this;
    }
}
exports.ResultBuilder = ResultBuilder;
/**
 * Utility function to assist in building controller results.
 * @param body The body data to return as the result.
 */
function result(body) {
    return new ResultBuilder(body);
}
exports.result = result;
//# sourceMappingURL=method-result.js.map