import { JSONSchema6 } from "json-schema";
export interface BodySettings {
    /**
     * Whether a request body is required on this method.
     */
    required?: boolean;
    /**
     * JSONSchema describing the request.
     */
    schema?: JSONSchema6;
}
/**
 * Annotates this parameter to receive the request body.
 */
export declare function body(settings?: BodySettings): ParameterDecorator;
/**
 * Settings for path parameters.
 */
export interface PathParamSettings {
    /**
     * JSONSchema describing this parameter.
     */
    schema?: JSONSchema6;
}
/**
 * Annotates this parameter to receive the given path parameter.
 *
 * If the path parameter has a definition in the method decorator,
 * it will be cocerced to the type supplied in that definition.
 * Otherwise, it will be a string.
 */
export declare function pathParam(paramName: string, settings?: PathParamSettings): ParameterDecorator;
/**
 * Settings for query parameters.
 */
export interface QueryParamSettings {
    /**
     * Whether this query parameter is required.
     */
    required?: boolean;
    /**
     * JSONSchema describing this query parameter.
     */
    schema?: JSONSchema6;
}
/**
 * Annotates this parameter to receive the given query parameter.
 *
 * If the path parameter has a definition in the method decorator,
 * it will be cocerced to the type supplied in that definition.
 * Otherwise, it will be a string.
 */
export declare function queryParam(paramName: string, settings?: QueryParamSettings): ParameterDecorator;
/**
 * Annotates the parameter to receive the express Request object.
 */
export declare function expressRequest(): ParameterDecorator;
/**
 * Annotates the parameter to receive the express Response object.
 */
export declare function expressResponse(): ParameterDecorator;
