import { JSONSchema6 } from "json-schema";
import { Method } from "../types";
/**
 * Settings for controller methods.
 */
export interface ControllerMethodSettings {
    summary?: string;
    description?: string;
    tags?: string[];
}
/**
 * Annotates this method to be a GET request method.
 */
export declare function get(): MethodDecorator;
/**
 * Annotates this method to be a GET request method.
 * @param path Path of this request handler relative to the controller.
 */
export declare function get(path: string): MethodDecorator;
/**
 * Annotates this method to be a GET request method.
 * @param settings Settings for this request method.
 */
export declare function get(settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a GET request method.
 * @param path Path of this request handler relative to the controller.
 * @param settings Settings for this request method.
 */
export declare function get(path: string, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a HEAD request method.
 */
export declare function head(): MethodDecorator;
/**
 * Annotates this method to be a HEAD request method.
 * @param path Path of this request handler relative to the controller.
 */
export declare function head(path: string): MethodDecorator;
/**
 * Annotates this method to be a HEAD request method.
 * @param settings Settings for this request method.
 */
export declare function head(settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a HEAD request method.
 * @param path Path of this request handler relative to the controller.
 * @param settings Settings for this request method.
 */
export declare function head(path: string, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a POST request method.
 */
export declare function post(): MethodDecorator;
/**
 * Annotates this method to be a POST request method.
 * @param path Path of this request handler relative to the controller.
 */
export declare function post(path: string): MethodDecorator;
/**
 * Annotates this method to be a POST request method.
 * @param settings Settings for this request method.
 */
export declare function post(settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a POST request method.
 * @param path Path of this request handler relative to the controller.
 * @param settings Settings for this request method.
 */
export declare function post(path: string, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a PUT request method.
 */
export declare function put(): MethodDecorator;
/**
 * Annotates this method to be a PUT request method.
 * @param path Path of this request handler relative to the controller.
 */
export declare function put(path: string): MethodDecorator;
/**
 * Annotates this method to be a PUT request method.
 * @param settings Settings for this request method.
 */
export declare function put(settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a PUT request method.
 * @param path Path of this request handler relative to the controller.
 * @param settings Settings for this request method.
 */
export declare function put(path: string, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a DELETE request method.
 */
export declare function del(): MethodDecorator;
/**
 * Annotates this method to be a DELETE request method.
 * @param path Path of this request handler relative to the controller.
 */
export declare function del(path: string): MethodDecorator;
/**
 * Annotates this method to be a DELETE request method.
 * @param settings Settings for this request method.
 */
export declare function del(settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a DELETE request method.
 * @param path Path of this request handler relative to the controller.
 * @param settings Settings for this request method.
 */
export declare function del(path: string, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a PATCH request method.
 */
export declare function patch(): MethodDecorator;
/**
 * Annotates this method to be a PATCH request method.
 * @param path Path of this request handler relative to the controller.
 */
export declare function patch(path: string): MethodDecorator;
/**
 * Annotates this method to be a PATCH request method.
 * @param settings Settings for this request method.
 */
export declare function patch(settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a PATCH request method.
 * @param path Path of this request handler relative to the controller.
 * @param settings Settings for this request method.
 */
export declare function patch(path: string, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a controller method responding
 * to a path.
 * @param method The HTTP Method to respond to.
 */
export declare function method(method: Method): MethodDecorator;
/**
 * Annotates this method to be a controller method responding
 * to a path.
 * @param method The HTTP Method to respond to.
 * @param path The path to respond at, relative to the controller path.
 */
export declare function method(method: Method, path: string): MethodDecorator;
/**
 * Annotates this method to be a controller method responding
 * to a path.
 * @param method The HTTP Method to respond to.
 * @param settings Additional settings for this method.
 */
export declare function method(method: Method, settings: ControllerMethodSettings): MethodDecorator;
/**
 * Annotates this method to be a controller method responding
 * to a path.
 * @param method The HTTP Method to respond to.
 * @param path The path to respond at, relative to the controller path.
 * @param settings Additional settings for this method.
 */
export declare function method(method: Method, path: string, settings: ControllerMethodSettings): MethodDecorator;
export interface ResponseSettings {
    /** A description of the meaning of this response */
    description?: string;
    /**
     * JSONSchema describing the shape of this response.
     */
    schema?: JSONSchema6;
}
export declare function response(statusCode: number, settings?: ResponseSettings): MethodDecorator;
/**
 * Specify the swagger documentation for the method.
 *
 * Using this decorator suppresses the auto-generation of swagger documentation for this method.
 *
 * @param swaggerPathDocs Additional swagger documentation to apply to the path.
 */
export declare function swaggerMethod(swaggerPathDocs: any): MethodDecorator;
