import { JSONSchema6 } from "json-schema";
import { Method } from "../types";
export interface ControllerMethodMetadata {
    method: Method;
    path?: string;
    summary?: string;
    description?: string;
    tags?: string[];
    queryParams?: Record<string, ParamMetadata>;
    pathParams?: Record<string, ParamMetadata>;
    request?: RequestMetadata;
    responses?: Record<number, ResponseMetadata>;
    handlerArgs?: ControllerMethodArgMetadata[];
    swaggerOverride?: any;
}
export interface RequestMetadata {
    required?: boolean;
    schema?: JSONSchema6;
}
export interface ResponseMetadata {
    description?: string;
    schema?: JSONSchema6;
}
export interface ParamMetadata {
    /**
     * Whether this parameter is required.
     */
    required?: boolean;
    schema?: JSONSchema6;
}
export declare type ControllerMethodArgMetadata = QueryParamControllerMethodArgMetadata | PathParamControllerMethodArgMetadata | BodyControllerMethodArgMetadata | RequestControllerMethodArgMetadata | ResponseControllerMethodArgMetadata;
export interface RequestControllerMethodArgMetadata {
    type: "request";
}
export interface ResponseControllerMethodArgMetadata {
    type: "response";
}
export interface QueryParamControllerMethodArgMetadata {
    type: "queryParam";
    paramName: string;
}
export interface PathParamControllerMethodArgMetadata {
    type: "pathParam";
    paramName: string;
}
export interface BodyControllerMethodArgMetadata {
    type: "body";
}
export declare function getControllerMethodMetadata(method: any): ControllerMethodMetadata | undefined;
export declare function setControllerMethodMetadata(method: any, metadata: ControllerMethodMetadata): void;
export declare function appendControllerMethodMetadata(method: any, metadata: Partial<ControllerMethodMetadata>): void;
