import { Request, Response, NextFunction } from "express";
import { ControllerMethodMetadata } from "../metadata";
import { Controller } from "../types";
export declare class MethodHandler {
    private _method;
    private _methodMetadata;
    private _controller;
    /**
     * Validator for the request body.
     */
    private _requestValidator;
    /**
     * Validators for responses indexed by status code.
     */
    private _responseValidators;
    /**
     * Validators for path params indexed by param name.
     */
    private _pathValidators;
    /**
     * Validators for query params indexed by param name.
     */
    private _queryValidators;
    constructor(_method: Function, _methodMetadata: ControllerMethodMetadata, _controller: Controller);
    /**
     * Handle an express request.
     *
     * This method is pre-bound.  Usage of `this` is safe when
     * this method is passed to the router.
     *
     * This method is async to assist with testing.  Its promise does
     * not need to be consumed, and errors will be passed to the
     * express `next` function.
     */
    handleRequest(req: Request, res: Response, next: NextFunction): Promise<void>;
    private _executeRequest;
    private _validateRequest;
    private _validateResponse;
    private _collectMethodArgs;
    private _collectArg;
    private _collectPathParam;
    private _collectQueryParam;
}
